module.exports = defineTest({
	description:
		'does not assume string.replace has side effects when called with a string as second argument'
});
